<?php
/**
 * @file
 * Administration page callbacks for the Election module.
 */

/**
 * Page callback for editing an election, path: election/%election/edit.
 *
 * @param object $election
 *   The election object (loaded by the menu system).
 *
 * @return array
 *   Render array generated by Form API for the form: election_form.
 */
function election_page_edit($election) {

  $type = _election_type_get_info($election->type);
  $title = t(
    'Edit @type: %title',
    array(
      '@type' => $type['name'],
      '%title' => $election->title,
    )
  );

  drupal_set_title($title, PASS_THROUGH);
  election_set_breadcrumb($election);

  module_load_include('inc', 'election', 'election.forms');

  return drupal_get_form('election_form', $election);
}

/**
 * Page callback for adding an election, path: elections/add/%type.
 *
 * @param string $type_machine_name
 *   The machine name of the election type (bundle key).
 *
 * @return array
 *   Render array generated by Form API for the form: election_form.
 */
function election_page_add($type_machine_name) {

  if (!$type = _election_type_get_info($type_machine_name)) {
    return MENU_NOT_FOUND;
  }

  $election = entity_get_controller('election')->create(array('type' => $type_machine_name));

  drupal_set_title(
    t('Add new @type', array('@type' => $type['name'])),
    PASS_THROUGH
  );

  module_load_include('inc', 'election', 'election.forms');

  return drupal_get_form('election_form', $election);

}
